@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2011 Licq developers
+ * Copyright (C) 2011, 2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,30 +20,21 @@
 #ifndef LICQAOSD_PLUGIN_H
 #define LICQAOSD_PLUGIN_H
 
-#include <licq/plugin/generalplugin.h>
+#include <licq/plugin/generalpluginhelper.h>
 
-
-class AosdPlugin : public Licq::GeneralPlugin
+class AosdPlugin : public Licq::GeneralPluginHelper
 {
 public:
-  AosdPlugin(Params& p);
+  AosdPlugin();
 
-  // From Licq::GeneralPlugin
-  std::string name() const;
-  std::string description() const;
-  std::string version() const;
-  std::string usage() const;
-  std::string configFile() const;
+  // From Licq::PluginInterface
+  int run();
+
+  // From Licq::GeneralPluginInterface
   bool isEnabled() const;
 
-protected:
-  // From Licq::GeneralPlugin
-  bool init(int argc, char** argv);
-  int run();
-  void destructor();
-
 private:
-  bool blocked;
+  bool myBlocked;
 };
 
 #endif
