@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010-2012 Licq developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2010-2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Please refer to the COPYRIGHT file distributed with this source
  * distribution for the names of the individual contributors.
@@ -34,8 +34,6 @@
 #include <gloox/message.h>
 #include <licq/logging/log.h>
 
-#define TRACE() gLog.debug("In SessionManager::%s()", __func__)
-
 using namespace LicqJabber;
 
 using Licq::gLog;
@@ -136,8 +134,7 @@ void SessionManager::handleMessage(
   const bool urgent = message.findExtension(gloox::ExtAttention) != NULL;
 
   time_t sent = ::time(NULL);
-  if (const gloox::DelayedDelivery* delayed
-      = message.findExtension<gloox::DelayedDelivery>(gloox::ExtDelay))
+  if (const gloox::DelayedDelivery* delayed = message.when())
   {
     struct tm tm;
     ::memset(&tm, 0, sizeof(tm));
