@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2004-2012 Licq developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2004-2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,8 +21,9 @@
 #include <cstring>
 #include "msnbuffer.h"
 
-using namespace std;
 using namespace LicqMsn;
+using std::list;
+using std::string;
 
 CMSNBuffer::CMSNBuffer(CMSNBuffer &b)
   : Licq::Buffer(b)
