@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2007-2012 Licq developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2007-2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -171,7 +171,7 @@ void ContactUserData::update(const Licq::User* u, unsigned long subSignal)
     myInVisibleList = u->VisibleList();
   }
 
-  if (myUserId.protocolId() == LICQ_PPID)
+  if (myUserId.protocolId() == ICQ_PPID)
   {
     const Licq::IcqUser* icquser = dynamic_cast<const Licq::IcqUser*>(u);
 
@@ -182,6 +182,12 @@ void ContactUserData::update(const Licq::User* u, unsigned long subSignal)
       mySharedFilesStatus = icquser->sharedFilesStatus();
     }
   }
+  else
+  {
+    myPhoneFollowMeStatus = Licq::IcqPluginInactive;
+    myIcqPhoneStatus = Licq::IcqPluginInactive;
+    mySharedFilesStatus = Licq::IcqPluginInactive;
+  }
 
   updateExtendedStatus();
 
@@ -321,7 +327,7 @@ void ContactUserData::updateExtendedStatus()
   if (myStatusInvisible)
     myExtendedStatus |= ContactListModel::InvisibleStatus;
 
-  if (myStatusTyping && myUserId.protocolId() == LICQ_PPID)
+  if (myStatusTyping)
     myExtendedStatus |= ContactListModel::TypingStatus;
 
   if (myPhoneFollowMeStatus == Licq::IcqPluginActive)
