@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2011 Licq developers
+ * Copyright (C) 1999-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,10 +62,6 @@ class SystemMenu;
 class UserEventCommon;
 class UserView;
 
-#ifdef USE_KDE
-class LicqKIMIface;
-#endif
-
 //=====MainWindow===============================================================
 class MainWindow : public QWidget
 {
@@ -81,10 +77,6 @@ public:
 
   QString usprintfHelp;
 
-#ifdef USE_KDE
-    LicqKIMIface* kdeIMInterface;
-#endif
-
   // Functions
   void CreateUserView();
 
@@ -104,7 +96,6 @@ public slots:
    */
   void slot_updatedList(unsigned long subSignal);
 
-  void slot_pluginUnloaded(unsigned long ppid);
   void updateGroups(bool initial = false);
 
   void showHints();
@@ -185,8 +176,6 @@ private slots:
   void prevGroup();
 
   void slot_logon();
-  void slot_protocolPlugin(unsigned long);
-  void slot_updateContactList();
   void slot_updatedUser(const Licq::UserId& userId, unsigned long subSignal, int argument);
 
   /**
