@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2007-2011 Licq developers
+ * Copyright (C) 2007-2011, 2013 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,13 +17,14 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "plugin.h"
-
 #include "config.h"
+
+#include "plugin.h"
 #include "pluginversion.h"
 
 #include <cstdio>
 #include <QApplication>
+#include <QMetaType>
 #include <QString>
 
 #ifdef USE_KDE
@@ -34,86 +35,35 @@
 # include <QStyleFactory>
 #endif
 
-#include <licq/daemon.h>
-#include <licq/plugin/generalbase.h>
+#include <licq/event.h>
 #include <licq/logging/log.h>
+#include <licq/pluginsignal.h>
 #include <licq/version.h>
 
 #include "core/gui-defines.h"
 #include "core/licqgui.h"
 
+Q_DECLARE_METATYPE(boost::shared_ptr<const Licq::PluginSignal>);
+Q_DECLARE_METATYPE(boost::shared_ptr<const Licq::Event>);
+
 using namespace LicqQtGui;
 /* TRANSLATOR LicqQtGui::QtGuiPlugin */
 
 QtGuiPlugin* LicqQtGui::gQtGuiPlugin = NULL;
 
-QtGuiPlugin::QtGuiPlugin(Licq::GeneralPlugin::Params& p)
-  : Licq::GeneralPlugin(p),
-    myArgc(0),
+QtGuiPlugin::QtGuiPlugin()
+  : myArgc(0),
     myArgv(NULL)
 {
   assert(gQtGuiPlugin == NULL);
   gQtGuiPlugin = this;
-}
 
-std::string QtGuiPlugin::name() const
-{
-  return DISPLAY_PLUGIN_NAME;
-}
-
-std::string QtGuiPlugin::description() const
-{
-#ifdef USE_KDE
-  return "KDE4 based GUI";
-#else
-  return "Qt4 based GUI";
-#endif
-}
-
-std::string QtGuiPlugin::version() const
-{
-  return PLUGIN_VERSION_STRING;
-}
-
-std::string QtGuiPlugin::usage() const
-{
-  static QString usage = QString(
-    "Usage:  Licq [options] -p %1 -- [-hdD] [-s skinname] [-i iconpack] [-e extendediconpack]"
-    "\n"
-    " -h : this help screen\n"
-    " -d : start hidden (dock icon only)\n"
-    " -D : disable dock icon for this session (does not affect dock icon settings)\n"
-    " -s : set the skin to use (must be in %2%3%4)\n"
-    " -i : set the icons to use (must be in %2%3%5)\n"
-    " -e : set the extended icons to use (must be in %2%3%6)"
-    )
-    .arg(PLUGIN_NAME)
-      .arg(Licq::gDaemon.baseDir().c_str())
-    .arg(QTGUI_DIR)
-    .arg(SKINS_DIR)
-    .arg(ICONS_DIR)
-    .arg(EXTICONS_DIR)
-    ;
-
-  return usage.toLatin1().constData();
-}
-
-std::string QtGuiPlugin::configFile() const
-{
-  return QTGUI_CONFIGFILE;
+  qRegisterMetaType< boost::shared_ptr<const Licq::PluginSignal> >();
+  qRegisterMetaType< boost::shared_ptr<const Licq::Event> >();
 }
 
 bool QtGuiPlugin::init(int argc, char** argv)
 {
-  for (int i = 1; i < argc; i++)
-  {
-    if (strcmp(argv[i], "-h") == 0)
-    {
-      printf("%s\n", usage().c_str());
-      return false;
-    }
-  }
-
   if (qApp != NULL)
   {
     Licq::gLog.error("A Qt application is already loaded.\n"
@@ -168,15 +118,39 @@ int QtGuiPlugin::run()
   return result;
 }
 
-void QtGuiPlugin::destructor()
+void QtGuiPlugin::shutdown()
 {
-  delete this;
+  emit pluginShutdown();
 }
 
-
-Licq::GeneralPlugin* QtGuiPluginFactory(Licq::GeneralPlugin::Params& p)
+bool QtGuiPlugin::isEnabled() const
 {
-  return new LicqQtGui::QtGuiPlugin(p);
+  // Always enabled
+  return true;
 }
 
-LICQ_GENERAL_PLUGIN_DATA(&QtGuiPluginFactory);
+void QtGuiPlugin::enable()
+{
+  // Always enabled
+}
+
+void QtGuiPlugin::disable()
+{
+  // Always enabled
+}
+
+bool QtGuiPlugin::wantSignal(unsigned long signalType) const
+{
+  return (signalType & Licq::PluginSignal::SignalAll) != 0;
+}
+
+void QtGuiPlugin::pushSignal(
+    boost::shared_ptr<const Licq::PluginSignal> signal)
+{
+  emit pluginSignal(signal);
+}
+
+void QtGuiPlugin::pushEvent(boost::shared_ptr<const Licq::Event> event)
+{
+  emit pluginEvent(event);
+}
