@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2011 Licq developers
+ * Copyright (C) 1999-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -191,7 +191,7 @@ QWidget* Settings::Skin::createPageSkin(QWidget* parent)
   layIconSets->addLayout(layEmoticon);
 
   // Buttons
-  QPushButton* btnEdit = new QPushButton(tr("&Edit Skin"));
+  QPushButton* btnEdit = new QPushButton(tr("&Edit Skin..."));
   connect(btnEdit, SIGNAL(clicked()), SLOT(editSkin()));
   laySkin->addWidget(btnEdit);
 
