@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2008-2012 Licq developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2008-2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ UserDlg::UserDlg(const Licq::UserId& userId, QWidget* parent)
   Support::setWidgetProps(this, "UserDialog");
   setAttribute(Qt::WA_DeleteOnClose, true);
 
-  myIsOwner = Licq::gUserManager.isOwner(myUserId);
+  myIsOwner = myUserId.isOwner();
 
   QVBoxLayout* top_lay = new QVBoxLayout(this);
 
