@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2011-2012 Licq developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2011-2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,8 +61,10 @@ public:
 private:
   /**
    * Save the current set of rules to file
+   *
+   * @param oldCount Highest rule number to remove from file
    */
-  void saveRules();
+  void saveRules(int oldCount);
 
 
   Licq::FilterRules myRules;
