@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq developers
+ * Copyright (C) 2010,2012 Licq Developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 
 using Licq::Pipe;
 
+namespace LicqTest {
+
 TEST(Pipe, create)
 {
   Pipe pipe;
@@ -60,3 +62,5 @@ TEST(Pipe, readWriteMultipleChars)
   EXPECT_EQ('b', pipe.getChar());
   EXPECT_EQ('c', pipe.getChar());
 }
+
+} // namespace LicqTest
